@@ -1,11 +1,11 @@
 /* -*-pgsql-c-*- */
 /*
- * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.12 2004/02/27 10:15:57 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/child.c,v 1.14 2004/03/24 02:26:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
  *
- * Copyright (c) 2003	Tatsuo Ishii
+ * Copyright (c) 2003, 2004	Tatsuo Ishii
  *
  * Permission to use, copy, modify, and distribute this software and
  * its documentation for any purpose and without fee is hereby
@@ -86,6 +86,7 @@ void do_child(int unix_fd, int inet_fd)
 
 	for (;;)
 	{
+		int major;
 		int connection_reuse = 1;
 		int ssl_request = 0;
 
@@ -112,7 +113,8 @@ void do_child(int unix_fd, int inet_fd)
 		}
 
 		/* V3(7.4 or later) protocol? */
-		if ((ntohl(sp->protoVersion)>>16) > 2)
+		major = sp->protoVersion >> 16;
+		if (major < 1234 && major > 2)
 		{
 			static char *msg = "Sorry, we do not support V3 protocol";
 
@@ -128,6 +130,40 @@ void do_child(int unix_fd, int inet_fd)
 			continue;
 		}
 
+		/* cancel request? */
+		if (ntohl(sp->protoVersion) == 0x04D2162E)		/* 0x04D2162F = 12345678 */
+		{
+			int	len;
+			int fd;
+			POOL_CONNECTION *con;
+			CancelPacket *cp = (CancelPacket *)sp;
+
+			pool_debug("Cancel request received");
+
+			if (*pool_config.current_backend_host_name == '\0')
+				fd = connect_unix_domain_socket((POOL_CONNECTION_POOL *)NULL);
+			else
+				fd = connect_inet_domain_socket((POOL_CONNECTION_POOL *)NULL);
+
+			if (fd < 0)
+			{
+				pool_error("Could not create socket for sending cancel request");
+				continue;
+			}
+
+			con = pool_open(fd);
+			if (con == NULL)
+				continue;
+
+			len = htonl(sizeof(len) + sizeof(CancelPacket));
+			pool_write(con, &len, sizeof(len));
+
+			if (pool_write_and_flush(con, cp, sizeof(CancelPacket)) < 0)
+				pool_error("Could not send cancel request packet");
+
+			continue;
+		}
+
 		/* SSL? */
 		if (ntohl(sp->protoVersion) == 0x04D2162F)		/* 0x04D2162F = 12345679 */
 		{
