@@ -1,7 +1,7 @@
 /* -*-pgsql-c-*- */
 /*
  *
- * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.8 2004/02/28 14:06:22 t-ishii Exp $
+ * $Header: /home/t-ishii/repository/pgpool/pool.h,v 1.9 2004/03/24 02:26:51 t-ishii Exp $
  *
  * pgpool: a language independent connection pool server for PostgreSQL 
  * written by Tatsuo Ishii
@@ -130,6 +130,13 @@ typedef struct StartupPacket
 	char		tty[SM_TTY];	/* Tty for debug output */
 } StartupPacket;
 
+typedef struct CancelPacket
+{
+	int			protoVersion;		/* Protocol version */
+	int			pid;	/* bcckend process id */
+	int			key;	/* cancel key */
+} CancelPacket;
+
 #define Max(x, y)		((x) > (y) ? (x) : (y))
 #define Min(x, y)		((x) < (y) ? (x) : (y))
 
@@ -178,4 +185,7 @@ void notice_backend_error(void);
 void pool_connection_pool_timer(POOL_CONNECTION_POOL *backend);
 RETSIGTYPE pool_backend_timer_handler(int sig);
 
+int connect_inet_domain_socket(POOL_CONNECTION_POOL *p);
+int connect_unix_domain_socket(POOL_CONNECTION_POOL *p);
+
 #endif /* POOL_H */
